package FDN::Adsl::Controller::Cloture;

use strict;
use warnings;
use base 'FDN::Adsl::Controller::Base';

use FDN::Web::Forms;

use FDN::Adsl::Basic;
use FDN::Adsl::New;
use FDN::Adsl::Utils;
use FDN::Adsl::Factu;

__PACKAGE__->config->{'namespace'} = 'adsl/cloture';


sub _new :Path('new') {
	my ( $self, $c ) = @_;

	$c->detach('Base','eject_error',[ "On n'dite pas les clotures comme a !" ]);
### 	my $vars = $c->req->params;
### 	my $creance;
### 
### 	my $form = form_creance($vars);
### 	my $crid = $vars->{'id'};
### 
### 	if ( $vars->{'do'} ne 'yes' ) {
### 		renseigne_creance($vars,$crid);
### 		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
### 	}
### 	if ( !check_transition($form,$vars) ) {
### 		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
### 	}
### 	modifie_creance($vars,$crid);
### 	my $from = $vars->{'from'};
### 	$c->detach('Base','back_from', [$from]);
}

sub liste :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	if ( $vars->{'annees'} ) {
		my @cls = toutes_clotures();
		my $annees = {};
		for my $cl ( @cls ) {
			my $date = $cl->{'CLOTURE_DATE'};
			$date =~ s/^(\d{4}).*$/$1/;
			$annees->{$date} //= 0;
			$annees->{$date}++;
		}
		my $page = $c->forward('TT','partial',['annees_clotures.tt',{ annees => $annees }]);
		$c->detach('Base','eject_page',[$page]);
	} elsif ( $vars->{'recentes'} ) {
		my $limit = $vars->{'recentes'};
		my @cls = clotures_recentes($limit);
		my $page = $self->large_table_2d($c, 'cloture', \@cls, "Clotures rcentes", {
			'Clore un mois' => '/adsl/cloture/clore',
			'Clotures par annes' => '?annees=1'
		});
		$c->detach('Base','eject_page',[$page]);
	} elsif ( $vars->{'annee'} ) {
		my $annee = $vars->{'annee'};
		my @cls = cloture_par_annee($annee);
		my $page = $self->large_table_2d($c, 'cloture', \@cls, "Clotures pour l'anne $annee", {
			'Clotures par annes' => '?annees=1'
		});
		$c->detach('Base','eject_page',[$page]);
	}

	$c->detach('Base','eject_error',["C'est idiot de vouloir lister toutes les clotures"]);
}

sub view :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $page;

	my $form = form_read('adsl/form/view.cfg','vcloture');
	if ( $vars->{'do'} ne 'yes' ) {
        	$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}
	if ( !check_transition($form,$vars) ) {
        	$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}

	my $cid = $vars->{'cid'};
	my $cloture = $vars->{'cloture'};

	if ( !$cid and !$cloture ) {
		add_form_error('mandatory',"Il faut quand meme renseigner un des deux champs");
		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}

	my $cl;
	if ( $cid ) {
		$cl = cloture_par_id($cid);
	} else {
		$cloture =~ /^(\d\d)\/(\d{4})/;
		my $dt = "$2$1";
		$cl = cloture_par_date($dt);
	}

	if (! defined $cl ) {
		$c->detach('Base','eject_error',["Cette cloture n'existe pas"]);
	}

	$cid = $cl->{'CLOTURE_ID'};
	$page = $self->small_table_1d($c,'cloture',$cl,"Description de la cloture");

	my @crs = creance_par_cloture_id($cid);
	$page .= $self->large_table_2d_pognon($c,'creance','CREANCE',\@crs,"Creances associees");

	$c->detach('Base','eject_page',[$page]);
}

sub clore :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;

	my $last = clotures_recentes(1);
	my $date = $last->{'CLOTURE_DATE'};
	$date =~ /^(\d\d\d\d)(\d\d)$/;
	my ( $annee, $mois ) = ( $1, $2 );

	my $page = '<h3>Dernire cloture connue: anne '.$annee.', mois '.$mois.'</h3>';
	$mois++;
	if ( $mois > 12 ) {
		$annee++;
		$mois='01'; 
	}
	$page .= '<p>Prochaine cloture raisonnable: anne '.$annee.', mois '.$mois.'</p>';
	$page .= '<p>Les valeurs par dfaut ont t positionnes en ce sens.</p>';
	$vars->{'mois'} //= 'mois'.$mois;
	$vars->{'annee'} //= 'annee'.$annee;

	my $form = form_read('adsl/form/factu.cfg','cmois');
	if ( $vars->{'do'} ne 'yes' ) {
		$page .= affiche_form($form,$vars);
		$c->detach('Base','eject_page', [ $page ] );
	}
	if ( !check_transition($form,$vars) ) {
		$page .= affiche_form($form,$vars);
		$c->detach('Base','eject_page', [ $page ] );
	}

	# Cloture effective du mois
	$annee = $vars->{annee};
	$annee =~ s/^annee//;
	$mois = $vars->{mois};
	$mois  =~ s/^mois//;
	
	my $clid = cloture_mois($annee,$mois);
	if ( $clid ) {
		$c->res->redirect('/adsl/cloture/view?cid='.$clid.'&do=yes');
	}

	$c->detach('Base','eject_error', [ "chec de la cloture. Il faut plucher les logs." ] );

}

1;
