package FDN::Adsl::Controller::Creance;

use strict;
use warnings;
use base 'FDN::Adsl::Controller::Base';

use FDN::Web::Array;
use FDN::Web::Forms;

use FDN::Adsl::Basic;
use FDN::Adsl::Utils;
use FDN::Adsl::New;

__PACKAGE__->config->{'namespace'} = 'adsl/creance';


sub _new :Path('new') {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $creance;

	my $form = form_creance($vars);
	my $crid = $vars->{'id'};

	if ( $vars->{'do'} ne 'yes' ) {
		renseigne_creance($vars,$crid);
		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}
	if ( !check_transition($form,$vars) ) {
		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}
	$crid = modifie_creance($vars,$crid);

	my $from = $vars->{'from'};
	$from //= 'creance'.$crid;
	$c->detach('Base','back_from', [$from]);
}

sub liste :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $page;

	if ( $vars->{'state'} ) {
		my $state = $vars->{'state'};
		$c->log->info("Liste des creances dont l'etat est '$state'");
		my @crs   = creance_par_etat($state);
		$page  = $self->large_table_2d_pognon($c,'creance','CREANCE',\@crs,"Liste des crances etat=$state");
		$c->detach('Base','eject_page',[$page]);
	}
	if ( $vars->{'client'} ) {
		my $cid = $vars->{'client'};
		$c->log->info("Liste des creances sur le client '$cid'");
		my $creances = [ creance_par_client_id($cid) ];
		$page = $self->large_table_2d($c,'creance',$creances,"Crances de l'abonn", {
			'Ajouter' => "/adsl/creance/new?client=$cid&from=client$cid"
		});
	}

	if ( $page ) {
		$c->detach('Base','eject_page',[$page]);
	}
		
	$c->detach('Base','eject_error',["C'est idiot de vouloir lister des crances en vrac"]);
}

sub view :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $page;

	my $form = form_read('adsl/form/view.cfg','vcreance');
	if ( $vars->{'do'} ne 'yes' ) {
		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}
	if ( !check_transition($form,$vars) ) {
		$c->detach('Base','eject_page',[affiche_form($form,$vars)]);
	}

	my $cid = $vars->{'cid'};
	my $creance = creance_par_id($cid);

	if ( ! defined $creance) {
		$c->detach('Base','eject_error',["Cette crance n'existe pas."]);
	}

        $page .= $self->small_table_1d($c,'creance',$creance,"Une creance", {
                'Edition' => "/adsl/creance/new?id=$cid&from=creance$cid"
        });

	$c->detach('Base','eject_page',[ $page ]);
}

1;
