package FDN::Adsl::Controller::Ligne;

use strict;
use warnings;
use base 'FDN::Adsl::Controller::Base';

use FDN::Common::Config;
use FDN::Web::Array;
use FDN::Web::Forms;

use FDN::Adsl::Basic;
use FDN::Adsl::Infos;
use FDN::Adsl::Liste;
use FDN::Adsl::New;
use FDN::Adsl::Utils;

__PACKAGE__->config->{'namespace'} = 'adsl/ligne';

sub liste :Local {
	my ( $self, $c ) = @_;

	my $page;
	my $cid = $c->req->param('cid');
	if ( $cid ) {
		my $lignes = [ ligne_par_client_id($cid) ];
		$page = $self->large_table_2d($c,'ligne',$lignes, 'Lignes de l\'abonn');
	} else {
		my $sort = $c->req->param('sort');
		$page = liste_lignes($sort);
	}
	
	$c->detach('Base','eject_page', [ $page ] );
}

sub view :Local {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $page;

	my $form = form_read('adsl/form/view.cfg','vligne');

	if ( $vars->{'do'} ne 'yes' ) {
		$page = affiche_form($form,$vars);
	} elsif ( !check_transition($form,$vars) ) {
		$page = affiche_form($form,$vars);
	}

	my $lid = $vars->{'lid'};
	my $tel = $vars->{'tel'};
	$tel =~ s/ //g;
	$tel =~ s/^\+33/0/;

	if ( !$page && ! $lid && ! $tel ) {
		add_form_error('mandatory',"Il faut quand meme renseigner un des deux champs");
		$page = affiche_form($form,$vars);
	}

	if ( $page ) {
		$c->detach('Base','eject_page',[ $page ]);
	}

	my $ligne;
	if ( $lid ) {
		$ligne = ligne_par_id($lid);
	} else {
		$ligne = ligne_par_tel($tel);
	}

	if ( ! defined $ligne ) {
		$c->detach('Base','eject_error',["Cette ligne n'existe pas"]);
	}

	# peu importe par ou on sera arrive, on peut avoir besoin des 2
	$lid = $ligne->{'LIGNE_ID'};
	$tel = $ligne->{'LIGNE_TEL'};

	my $cid = $ligne->{'CLIENT_ID'};
	$page = $self->small_table_1d($c, 'ligne-detail', $ligne, "Description de la ligne ", {
		'Modifier' => '/adsl/ligne/new?id='.$lid
	});

	my $dpl = deploiement_par_ligne_id($lid);
	$page .= $self->small_table_1d($c, 'deploiement', $dpl);

	my $aid = $ligne->{'ADRESSE_ID'};
	my $adr = adresse_par_id($aid);
	$page .= $self->small_table_1d($c, 'adresse', $adr, "Adresse de la ligne ", {
		Modifier => '/adsl/adresse/new?id='.$aid.'&from=ligne'.$lid
	});

	my $user = raduser_par_ligne_id($lid);
	$page .= $self->small_table_1d($c, 'raduser', $user, "Compte radius associ");

	my $mandat = mandat_par_deploiement_id($dpl->{'DEPLOIEMENT_ID'});
	$page .= $self->small_table_1d($c, 'mandat',$mandat, "Mandat de dgroupage associ");

	my @validations = validation_par_ligne_id($lid);
	$page .= $self->large_table_2d($c, 'validation', \@validations, 'Validations pour cette ligne');

	my @infos = toutes_infos_ligne($lid);
	$page .= $self->large_table_2d($c, 'infos', \@infos, "Informations sur la ligne", {
		'Numriser' => '/adsl/new-scan.cgi?ligne='.$lid.'&client='.$cid
	});

	$c->detach('Base','eject_page',[ $page ]);

}

sub _new :Path('new') {
	my ( $self, $c ) = @_;

	my $vars = $c->req->params;
	my $id = $vars->{id};

	my $form = form_ligne($vars);
	my $lid = $vars->{'id'};

	if ( $vars->{'do'} ne 'yes' ) {
		renseigne_ligne($vars,$lid);
		if ( defined $lid ) {
			my @infos = toutes_infos_ligne($lid);
			my $tmp = tableau_2d('adsl/rewrite.tbl','infos',\@infos);
			my $fld = $form->{'byname'}->{'infos'};
			form_set_field_value($fld,$tmp);
		}
		$c->detach('Base','eject_page',[ affiche_form($form,$vars) ]);
	}

	if ( !check_transition($form,$vars) ) {
		$c->detach('Base','eject_page',[ affiche_form($form,$vars) ]);
	}

	modifie_ligne($vars,$lid);
	$c->res->redirect("/adsl/ligne/view?lid=$lid&do=yes");
}


1;
